==> knative-model-6.8.0-sources.jar: io/fabric8/knative/serving/v1/ContainerStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContainerStatusFluent<A extends ContainerStatusFluent<A>> extends BaseFluent<A>{
  public ContainerStatusFluent() {
  }
  public ContainerStatusFluent(ContainerStatus instance) {
    instance = (instance != null ? instance : new ContainerStatus());

    if (instance != null) {
      this.withImageDigest(instance.getImageDigest());
      this.withName(instance.getName());
      this.withImageDigest(instance.getImageDigest());
      this.withName(instance.getName());
    }
  }
  private String imageDigest;
  private String name;
  public String getImageDigest() {
    return this.imageDigest;
  }
  public A withImageDigest(String imageDigest) {
    this.imageDigest=imageDigest; return (A) this;
  }
  public boolean hasImageDigest() {
    return this.imageDigest != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerStatusFluent that = (ContainerStatusFluent) o;
    if (!java.util.Objects.equals(imageDigest, that.imageDigest)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageDigest,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageDigest != null) { sb.append("imageDigest:"); sb.append(imageDigest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/serving/v1/ContainerStatusFluent.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ContainerStatusFluent<A extends ContainerStatusFluent<A>> extends BaseFluent<A>{
  public ContainerStatusFluent() {
  }
  
  public ContainerStatusFluent(ContainerStatus instance) {
    this.copyInstance(instance);
  }
  private String imageDigest;
  private String name;
  
  protected void copyInstance(ContainerStatus instance) {
    instance = (instance != null ? instance : new ContainerStatus());
  
    if (instance != null) {
        this.withImageDigest(instance.getImageDigest());
        this.withName(instance.getName());
        this.withImageDigest(instance.getImageDigest());
        this.withName(instance.getName());
      }
  }
  
  public String getImageDigest() {
    return this.imageDigest;
  }
  
  public A withImageDigest(String imageDigest) {
    this.imageDigest=imageDigest; return (A) this;
  }
  
  public boolean hasImageDigest() {
    return this.imageDigest != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerStatusFluent that = (ContainerStatusFluent) o;
    if (!java.util.Objects.equals(imageDigest, that.imageDigest)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(imageDigest,  name,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageDigest != null) { sb.append("imageDigest:"); sb.append(imageDigest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  

}
